1.0.0 API documentation: GLM_GTX_bit

| 1.0.0 API documentation

Functions
GLM_GTX_bit
Experimental extensions

## Functions
template<typename genIUType >
GLM_FUNC_DECL genIUType | highestBitValue (genIUType Value)
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | highestBitValue (vec< L, T, Q > const &value)
| Find the highest bit set to 1 in a integer variable and return its value. More...
template<typename genIUType >
GLM_FUNC_DECL genIUType | lowestBitValue (genIUType Value)
template<typename genIUType >
GLM_DEPRECATED GLM_FUNC_DECL genIUType | powerOfTwoAbove (genIUType Value)
| Return the power of two number which value is just higher the input value. More...
template<length_t L, typename T , qualifier Q>
GLM_DEPRECATED GLM_FUNC_DECL vec< L, T, Q > | powerOfTwoAbove (vec< L, T, Q > const &value)
| Return the power of two number which value is just higher the input value. More...
template<typename genIUType >
GLM_DEPRECATED GLM_FUNC_DECL genIUType | powerOfTwoBelow (genIUType Value)
| Return the power of two number which value is just lower the input value. More...
template<length_t L, typename T , qualifier Q>
GLM_DEPRECATED GLM_FUNC_DECL vec< L, T, Q > | powerOfTwoBelow (vec< L, T, Q > const &value)
| Return the power of two number which value is just lower the input value. More...
template<typename genIUType >
GLM_DEPRECATED GLM_FUNC_DECL genIUType | powerOfTwoNearest (genIUType Value)
| Return the power of two number which value is the closet to the input value. More...
template<length_t L, typename T , qualifier Q>
GLM_DEPRECATED GLM_FUNC_DECL vec< L, T, Q > | powerOfTwoNearest (vec< L, T, Q > const &value)
| Return the power of two number which value is the closet to the input value. More...

## Detailed Description

Include <glm/gtx/bit.hpp> to use the features of this extension.

Allow to perform bit operations on integer values

## Function Documentation

## ◆ highestBitValue() [1/2]

GLM_FUNC_DECL genIUType glm::highestBitValue | ( | genIUType | Value | ) |

See also
  GLM_GTX_bit

## ◆ highestBitValue() [2/2]

GLM_FUNC_DECL vec<L, T, Q> glm::highestBitValue | ( | vec< L, T, Q > const & | value | ) |

Find the highest bit set to 1 in a integer variable and return its value.

See also
  GLM_GTX_bit

## ◆ lowestBitValue()

GLM_FUNC_DECL genIUType glm::lowestBitValue | ( | genIUType | Value | ) |

See also
  GLM_GTX_bit

## ◆ powerOfTwoAbove() [1/2]

GLM_DEPRECATED GLM_FUNC_DECL genIUType glm::powerOfTwoAbove | ( | genIUType | Value | ) |

Return the power of two number which value is just higher the input value.

Deprecated, use ceilPowerOfTwo from GTC_round instead

See also
  GLM_GTC_round
  GLM_GTX_bit

## ◆ powerOfTwoAbove() [2/2]

GLM_DEPRECATED GLM_FUNC_DECL vec<L, T, Q> glm::powerOfTwoAbove | ( | vec< L, T, Q > const & | value | ) |

Return the power of two number which value is just higher the input value.

Deprecated, use ceilPowerOfTwo from GTC_round instead

See also
  GLM_GTC_round
  GLM_GTX_bit

## ◆ powerOfTwoBelow() [1/2]

GLM_DEPRECATED GLM_FUNC_DECL genIUType glm::powerOfTwoBelow | ( | genIUType | Value | ) |

Return the power of two number which value is just lower the input value.

Deprecated, use floorPowerOfTwo from GTC_round instead

See also
  GLM_GTC_round
  GLM_GTX_bit

## ◆ powerOfTwoBelow() [2/2]

GLM_DEPRECATED GLM_FUNC_DECL vec<L, T, Q> glm::powerOfTwoBelow | ( | vec< L, T, Q > const & | value | ) |

Return the power of two number which value is just lower the input value.

Deprecated, use floorPowerOfTwo from GTC_round instead

See also
  GLM_GTC_round
  GLM_GTX_bit

## ◆ powerOfTwoNearest() [1/2]

GLM_DEPRECATED GLM_FUNC_DECL genIUType glm::powerOfTwoNearest | ( | genIUType | Value | ) |

Return the power of two number which value is the closet to the input value.

Deprecated, use roundPowerOfTwo from GTC_round instead

See also
  GLM_GTC_round
  GLM_GTX_bit

## ◆ powerOfTwoNearest() [2/2]

GLM_DEPRECATED GLM_FUNC_DECL vec<L, T, Q> glm::powerOfTwoNearest | ( | vec< L, T, Q > const & | value | ) |

Return the power of two number which value is the closet to the input value.

Deprecated, use roundPowerOfTwo from GTC_round instead

See also
  GLM_GTC_round
  GLM_GTX_bit